@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Sequence, Optional, Any
+from typing import Sequence, Callable
 
 import numpy as np
 import tensorflow as tf
@@ -10,30 +10,33 @@ from .bert_mixin import BertDatasetMixin
 from .utils import serialize_example
 
 
+def _combine_xy(token_ids, type_ids, label):
+    return ((token_ids, type_ids), label)
+
+
+def _combine_x(token_ids, type_ids):
+    return ((token_ids, type_ids),)
+
+
 class ClassificationDataset(NLPDataset):
     def __init__(
         self,
         vocab: Vocab,
         labels: Sequence[str],
-        segmenter: Optional[str] = None,
-        X: Optional[Sequence[Any]] = None,
-        y: Optional[Sequence[Any]] = None,
-        csv_file: Optional[str] = None,
+        segmenter: str | None = None,
+        X: Sequence[str] | Sequence[Sequence[str]] | None = None,
+        y: Sequence[str] | None = None,
+        csv_file: str | None = None,
         in_memory: bool = True,
         has_label: bool = True,
         is_multilabel: bool = False,
-        is_pair_text: bool = False,
-        max_length: Optional[int] = None,
+        max_length: int | None = None,
         text_dtype: tf.DType = tf.int64,
-        label_dtype: tf.DType = tf.float32,
+        label_dtype: tf.DType = tf.int32,
         **kwargs,
     ):
         self.labels = list(labels)
-        self.is_pair_text = is_pair_text
         self.is_multilabel = is_multilabel
-        column_dtypes = ["str", "str"]
-        if self.is_pair_text:
-            column_dtypes.append("str")
         self.label2idx = dict(zip(labels, range(len(labels))))
         super().__init__(
             vocab,
@@ -45,7 +48,6 @@ class ClassificationDataset(NLPDataset):
             has_label=has_label,
             max_length=max_length,
             na_value="NULL",
-            column_dtypes=column_dtypes,
             text_dtype=text_dtype,
             label_dtype=label_dtype,
             **kwargs,
@@ -62,29 +64,53 @@ class ClassificationDataset(NLPDataset):
             for data in self._original_dataset.as_numpy_iterator()
         ]
 
-    @property
-    def batch_padding_shapes(self) -> list[tuple]:
-        shapes = [(None,), (None,)]
-        return shapes[: None if self.has_label else -1]
-
-    def _format_y(self, y: Sequence[Any]) -> list[Sequence[Any]]:
+    def y_row_to_col(self, y: Sequence[Sequence[str] | str]) -> list[Sequence[str]]:
         if isinstance(y[0], (list, tuple)):
-            y = ["|".join(map(str, yi)) for yi in y]
+            y = "|".join(y)
         return [y]
 
-    def py_label_binarizer(self, labels: list[str]) -> np.ndarray:
-        label2idx = self.label2idx
-        res = np.zeros(len(label2idx), dtype=np.float32)
-        res[[label2idx[label] for label in labels if label in label2idx]] = 1
-        return res
+    @property
+    def batch_padding_shapes(self) -> list[tuple[int | None]]:
+        shapes = [(None,), (None,), (None,)]
+        return shapes[: None if self.has_label else -1]
 
-    def py_label_transform(self, label: tf.Tensor) -> np.ndarray:
+    @property
+    def batch_padding_values(self) -> list[int]:
+        values = [np.int64(self.vocab[self.vocab.pad]), np.int64(0), -1]
+        return values[: None if self.has_label else -1]
+
+    def py_label_transform(self, label: bytes) -> np.ndarray:
         _label = super().py_label_transform(label)
         if self.is_multilabel:
             labels = _label.split("|")
         else:
             labels = [_label]
-        return self.py_label_binarizer(labels)
+        label_ids = [
+            self.label2idx[label] for label in labels if label in self.label2idx
+        ]
+        if len(label_ids) == 0:
+            # 没有标签的异常数据， 填入0， 以保证正常训练
+            # 抛出异常可能更合适
+            label_ids = [0]
+        return np.array(label_ids, dtype=np.int32)
+
+    def batchify(
+        self,
+        batch_size: int,
+        shuffle: bool = True,
+        training: bool = True,
+        shuffle_buffer_size: int | None = None,
+        after_batch: Callable | None = None,
+    ) -> tf.data.Dataset:
+        if after_batch is None:
+            after_batch = _combine_xy if self.has_label else _combine_x
+        return super().batchify(
+            batch_size,
+            shuffle=shuffle,
+            training=training,
+            shuffle_buffer_size=shuffle_buffer_size,
+            after_batch=after_batch,
+        )
 
     def to_tfrecord(self, filename: str) -> None:
         def func(text: np.ndarray, label: np.ndarray):
