@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Sequence, Optional
+from typing import Sequence
 import tempfile
 from functools import partial
 
@@ -14,19 +14,18 @@ from sknlp.vocab import Vocab
 
 
 class Tokenizer:
-    def __init__(self, vocab: Vocab, max_length: Optional[int] = None) -> None:
+    def __init__(self, vocab: Vocab) -> None:
         self.vocab = vocab
-        self.max_length = max_length
 
     def tokenize(self, text: str | Sequence[str]) -> list[list[str]] | list[str]:
         raise NotImplementedError()
 
 
 class JiebaTokenizer(Tokenizer):
-    def __init__(self, vocab: Vocab, max_length: Optional[int] = None) -> None:
-        super().__init__(vocab, max_length=max_length)
+    def __init__(self, vocab: Vocab) -> None:
+        super().__init__(vocab)
         with tempfile.NamedTemporaryFile("w+") as f:
-            for token in vocab.sorted_tokens[len(vocab.special_tokens) :]:
+            for token in vocab.sorted_tokens:
                 f.write(f"{token} {vocab._token_frequency.get(token, 1)}\n")
             f.flush()
             tokenizer = jieba.Tokenizer(dictionary=f.name)
@@ -35,20 +34,20 @@ class JiebaTokenizer(Tokenizer):
 
     def tokenize(self, text: str | Sequence[str]) -> list[list[str]] | list[str]:
         if isinstance(text, str):
-            return self.tokenizer(text)[: self.max_length]
+            return self.tokenizer(text)
         return [self.tokenize(t) for t in text]
 
 
 class CharTokenizer(Tokenizer):
     def tokenize(self, text: str | Sequence[str]) -> list[list[str]] | list[str]:
         if isinstance(text, str):
-            return list(text)[: self.max_length]
+            return list(text)
         return [self.tokenize(t) for t in text]
 
 
 class BertTokenizer(Tokenizer):
-    def __init__(self, vocab: Vocab, max_length: int) -> None:
-        super().__init__(vocab, max_length=max_length)
+    def __init__(self, vocab: Vocab) -> None:
+        super().__init__(vocab)
         self.tokenizer = tftext.BertTokenizer(
             tf.lookup.StaticVocabularyTable(
                 tf.lookup.KeyValueTensorInitializer(
@@ -78,8 +77,7 @@ class BertTokenizer(Tokenizer):
             return ragged_tokens.to_tensor(self.vocab.pad)
         tokens_list = ragged_tokens.to_list()
         tokens_list = [
-            [token.decode("UTF-8") for token in tokens[: self.max_length]]
-            for tokens in tokens_list
+            [token.decode("UTF-8") for token in tokens] for tokens in tokens_list
         ]
         if is_flat:
             return tokens_list[0]
@@ -87,14 +85,12 @@ class BertTokenizer(Tokenizer):
             return tokens_list
 
 
-def get_tokenizer(
-    name: str, vocab: Vocab, max_length: Optional[int] = None
-) -> Tokenizer:
-    if name == "jieba":
-        return JiebaTokenizer(vocab, max_length)
+def get_tokenizer(name: str, vocab: Vocab) -> Tokenizer:
+    if name == "jieba" or name == "word":
+        return JiebaTokenizer(vocab)
     elif name == "list" or name == "char":
-        return CharTokenizer(vocab, max_length)
+        return CharTokenizer(vocab)
     elif name == "bert" or name is None:
-        return BertTokenizer(vocab, max_length)
+        return BertTokenizer(vocab)
     else:
         raise ValueError("unknown segmenter %s" % name)
\ No newline at end of file
