@@ -1,6 +1,8 @@
 from .mlp import MLPLayer
 from .bilstm import BiLSTM
-from .bert_layer import BertLayer, BertPreprocessingLayer
+from .preprocessing_layer import PreprocessingLayer
+from .preprocessing_layer import BertPreprocessingLayer
+from .bert_layer import BertLayer
 from .bert_attention_mask import BertAttentionMaskLayer
 from .bert_lm import BertLMLossLayer
 from .bert_seq2seq import BertBeamSearchDecoder, BertDecodeCell
