@@ -13,132 +13,17 @@
 # limitations under the License.
 # =============================================================================
 from __future__ import annotations
-from typing import Sequence, Any, Optional, Callable
+from typing import Any, Callable
 
 import tensorflow as tf
 from tensorflow.keras.layers import Embedding, Dense, LayerNormalization, Dropout
 from tensorflow.keras.initializers import TruncatedNormal
 
-import tensorflow_text as tftext
-
 from sknlp.activations import gelu
 
 from .transformer_encoder_block import TransformerEncoderBlock
 
 
-@tf.keras.utils.register_keras_serializable(package="sknlp")
-class BertPreprocessingLayer(tf.keras.layers.Layer):
-    def __init__(
-        self,
-        vocab: Sequence[str],
-        cls_token: str = "[CLS]",
-        sep_token: str = "[SEP]",
-        max_length: int = 510,
-        return_offset: bool = False,
-        name: str = "bert_tokenize",
-        **kwargs,
-    ) -> None:
-        vocab: list = list(vocab)
-        self.cls_token = cls_token
-        self.sep_token = sep_token
-        self.max_length = max_length
-        if cls_token not in vocab:
-            vocab.append(cls_token)
-        if sep_token not in vocab:
-            vocab.append(sep_token)
-
-        self.max_chars_per_token = 1
-        for i, token in enumerate(vocab):
-            if token == cls_token:
-                self.cls_id = i
-            if token == sep_token:
-                self.sep_id = i
-            self.max_chars_per_token = max(self.max_chars_per_token, len(token))
-        self.vocab = vocab
-        self.return_offset = return_offset
-        super().__init__(name=name, **kwargs)
-
-    def build(self, input_shape: tf.TensorShape) -> None:
-        self.tokenizer = tftext.BertTokenizer(
-            tf.lookup.StaticVocabularyTable(
-                tf.lookup.KeyValueTensorInitializer(
-                    self.vocab,
-                    list(range(len(self.vocab))),
-                    key_dtype=tf.string,
-                    value_dtype=tf.int64,
-                ),
-                1,
-            ),
-            max_chars_per_token=self.max_chars_per_token,
-        )
-        super().build(input_shape)
-
-    def call(self, inputs: tf.Tensor | list[tf.Tensor]) -> list[tf.Tensor]:
-        inputs = tf.nest.flatten(inputs)
-        trimmer = tftext.WaterfallTrimmer(self.max_length)
-        if len(inputs) == 1:
-            if self.return_offset:
-                (token_ids, starts, ends) = self.tokenizer.tokenize_with_offsets(
-                    inputs[0]
-                )
-                starts = starts.merge_dims(-2, -1)
-                ends = ends.merge_dims(-2, -1)
-            else:
-                token_ids = self.tokenizer.tokenize(inputs[0])
-            flatten_ids = token_ids.merge_dims(-2, -1)
-            ids, type_ids = tftext.combine_segments(
-                trimmer.trim([flatten_ids]),
-                start_of_sequence_id=self.cls_id,
-                end_of_segment_id=self.sep_id,
-            )
-            tensors: list[tf.Tensor] = [ids.to_tensor(), type_ids.to_tensor()]
-            if self.return_offset:
-                tensors.append(starts.to_tensor())
-                tensors.append(ends.to_tensor())
-            return tensors
-        elif len(inputs) == 2:
-            query, context = inputs
-            query_token_ids = self.tokenizer.tokenize(query)
-            if self.return_offset:
-                # TODO: 句对输入仅输出第二句的start和end索引是否合理,
-                #       需要根据具体任务设计判断, 如阅读理解
-                (
-                    context_token_ids,
-                    starts,
-                    ends,
-                ) = self.tokenizer.tokenize_with_offsets(context)
-                starts = starts.merge_dims(-2, -1)
-                ends = ends.merge_dims(-2, -1)
-            else:
-                context_token_ids = self.tokenizer.tokenize(context)
-            query_flatten_ids = query_token_ids.merge_dims(-2, -1)
-            context_flatten_ids = context_token_ids.merge_dims(-2, -1)
-            token_ids, type_ids = tftext.combine_segments(
-                trimmer.trim([query_flatten_ids, context_flatten_ids]),
-                start_of_sequence_id=self.cls_id,
-                end_of_segment_id=self.sep_id,
-            )
-
-            tensors: list[tf.Tensor] = [token_ids.to_tensor(), type_ids.to_tensor()]
-            if self.return_offset:
-                tensors.append(starts.to_tensor())
-                tensors.append(ends.to_tensor())
-            return tensors
-        else:
-            raise ValueError(
-                f"The length of inputs must be 1 or 2, bug get {len(inputs)}."
-            )
-
-    def get_config(self) -> dict[str, Any]:
-        return {
-            **super().get_config(),
-            "vocab": self.vocab,
-            "cls_token": self.cls_token,
-            "sep_token": self.sep_token,
-            "return_offset": self.return_offset,
-        }
-
-
 @tf.keras.utils.register_keras_serializable(package="sknlp")
 class BertLayer(tf.keras.layers.Layer):
     """
@@ -148,7 +33,7 @@ class BertLayer(tf.keras.layers.Layer):
     def __init__(
         self,
         vocab_size: int = 100,
-        embedding_size: Optional[int] = 768,
+        embedding_size: int | None = 768,
         hidden_size: int = 768,
         num_layers: int = 12,
         num_attention_heads: int = 12,
@@ -326,7 +211,7 @@ class BertLayer(tf.keras.layers.Layer):
         rel_logits = self.relationship_dense(cls_output)
         return cls_output, encoder_outputs, lm_logits, rel_logits
 
-    def get_config(self):
+    def get_config(self) -> dict[str, Any]:
         return {
             **super().get_config(),
             "vocab_size": self.vocab_size,
