@@ -2,6 +2,9 @@ from .precision_recall_f1 import (
     PrecisionWithLogits,
     RecallWithLogits,
     FBetaScoreWithLogits,
+    SparsePrecisionWithLogits,
+    SparseRecallWithLogits,
+    SparseFBetaScoreWithLogits,
 )
 from .accuracy import BinaryAccuracyWithLogits, AccuracyWithLogits
 
@@ -12,4 +15,7 @@ __all__ = [
     "PrecisionWithLogits",
     "RecallWithLogits",
     "FBetaScoreWithLogits",
+    "SparsePrecisionWithLogits",
+    "SparseRecallWithLogits",
+    "SparseFBetaScoreWithLogits",
 ]
