@@ -3,6 +3,7 @@ from typing import Sequence, Optional, Any, Callable
 
 import json
 import os
+import math
 import itertools
 from collections import Counter
 
@@ -15,6 +16,7 @@ import tensorflow as tf
 import sknlp
 from sknlp.callbacks import default_supervised_model_callbacks
 from sknlp.optimizers import AdamOptimizer
+from sknlp.optimizers.learning_rate_scheduler import CosineDecayWithWarmup
 from sknlp.vocab import Vocab
 from sknlp.data import NLPDataset
 
@@ -192,10 +194,12 @@ class BaseNLPModel:
         X: Sequence[Any],
         y: Sequence[Any],
         dataset: NLPDataset,
+        n_samples: int | None = None,
         evaluation: bool = False,
     ) -> NLPDataset:
         assert X is not None or dataset is not None
         if dataset is not None:
+            dataset.size = n_samples
             return dataset
         dataset_class = self.dataset_class
         if evaluation:
@@ -234,33 +238,33 @@ class BaseNLPModel:
 
     def fit(
         self,
-        X: Sequence[Any] = None,
-        y: Sequence[Any] = None,
+        X: Sequence[Any] | None = None,
+        y: Sequence[Any] | None = None,
         *,
-        dataset: NLPDataset = None,
-        validation_X: Optional[Sequence[Any]] = None,
-        validation_y: Optional[Sequence[Any]] = None,
-        validation_dataset: NLPDataset = None,
+        n_samples: int | None = None,
+        dataset: NLPDataset | None = None,
+        validation_X: Sequence[Any] | None = None,
+        validation_y: Sequence[Any] | None = None,
+        validation_dataset: NLPDataset | None = None,
         batch_size: int = 128,
         n_epochs: int = 10,
         optimizer: str = "adam",
-        optimizer_kwargs: Optional[dict[str, Any]] = None,
+        optimizer_kwargs: dict[str, Any] | None = None,
         learning_rate: float = 1e-3,
+        learning_rate_warmup_percentile: float = 10,
         weight_decay: float = 0.0,
-        clip: Optional[float] = 5.0,
-        learning_rate_update_factor: float = 0.5,
-        learning_rate_update_epochs: int = 10,
-        learning_rate_warmup_steps: int = 0,
+        clip: float = 5.0,
         enable_early_stopping: bool = False,
-        early_stopping_patience: Optional[int] = None,
+        early_stopping_patience: int = 3,
         early_stopping_min_delta: float = 0.0,
         early_stopping_use_best_epoch: bool = True,
         early_stopping_monitor: int = 2,  # 1 for loss, 2 for metric
-        checkpoint: Optional[str] = None,
-        log_file: Optional[str] = None,
+        checkpoint: str | None = None,
+        log_file: str | None = None,
         verbose: int = 2
     ) -> None:
-        training_dataset = self.prepare_dataset(X, y, dataset)
+        training_dataset = self.prepare_dataset(X, y, dataset, n_samples=n_samples)
+        self._inference_kwargs["num_inputs"] = training_dataset.num_texts
         if (
             validation_X is None or validation_y is None
         ) and validation_dataset is None:
@@ -276,19 +280,28 @@ class BaseNLPModel:
                 batch_size, shuffle=False
             )
 
+        num_training_steps = math.ceil(training_dataset.size / batch_size) * n_epochs
+        learning_rate_warmup_steps = math.floor(
+            num_training_steps * (learning_rate_warmup_percentile / 100)
+        )
+
+        learning_rate_decay = CosineDecayWithWarmup(
+            learning_rate, learning_rate_warmup_steps, num_training_steps
+        )
+
         optimizer_kwargs = optimizer_kwargs or dict()
         optimizer_kwargs = {
-            "learning_rate": learning_rate,
+            "learning_rate": learning_rate_decay,
             "weight_decay": weight_decay,
             **optimizer_kwargs,
         }
-        if clip is not None:
+        if clip:
             optimizer_kwargs["global_clipnorm"] = clip
         self.compile_optimizer(optimizer, **optimizer_kwargs)
 
         monitor = "val_loss"
         monitor_direction = "min"
-        if early_stopping_monitor == 2 and self.get_monitor():
+        if early_stopping_monitor != 1 and self.get_monitor():
             monitor = self.get_monitor()
             monitor_direction = "max"
 
@@ -301,9 +314,6 @@ class BaseNLPModel:
                     checkpoint, self._get_model_filename_template()
                 )
         callbacks = default_supervised_model_callbacks(
-            learning_rate_update_factor=learning_rate_update_factor,
-            learning_rate_update_epochs=learning_rate_update_epochs,
-            learning_rate_warmup_steps=learning_rate_warmup_steps,
             has_validation_dataset=has_validation_dataset,
             enable_early_stopping=enable_early_stopping,
             early_stopping_monitor=monitor,
@@ -364,7 +374,7 @@ class BaseNLPModel:
 
     def save_vocab(self, directory: str, filename: str = "vocab.json") -> None:
         with open(os.path.join(directory, filename), "w", encoding="UTF-8") as f:
-            f.write(self.vocab.to_json())
+            f.write(json.dumps(self.vocab.get_config(), ensure_ascii=False))
 
     def save(self, directory: str) -> None:
         options = tf.saved_model.SaveOptions(experimental_custom_gradients=False)
@@ -381,7 +391,7 @@ class BaseNLPModel:
         with open(os.path.join(directory, "meta.json"), encoding="UTF-8") as f:
             meta = json.loads(f.read())
         with open(os.path.join(directory, "vocab.json")) as f:
-            vocab = Vocab.from_json(f.read())
+            vocab = Vocab.from_config(json.loads(f.read()))
         module = cls.from_config({"vocab": vocab, **meta})
         module._model = tf.keras.models.load_model(
             os.path.join(directory, cls._get_model_filename(epoch=epoch))
@@ -389,7 +399,7 @@ class BaseNLPModel:
         module._built = True
         return module
 
-    def export(self, directory: str, name: str, version: str = "0") -> None:
+    def export(self, directory: str, name: str, version: str = "0", **kwargs) -> None:
         d = os.path.join(directory, name, version)
 
         model: tf.keras.Model = tf.keras.models.model_from_json(
