@@ -20,7 +20,6 @@ class BertClassifier(DeepClassifier):
         self,
         classes: Sequence[str],
         is_multilabel: bool = True,
-        is_pair_text: bool = False,
         max_sequence_length: int = 120,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
@@ -33,7 +32,6 @@ class BertClassifier(DeepClassifier):
         super().__init__(
             classes,
             is_multilabel=is_multilabel,
-            is_pair_text=is_pair_text,
             algorithm="bert",
             num_fc_layers=num_fc_layers,
             fc_hidden_size=fc_hidden_size,
@@ -44,10 +42,6 @@ class BertClassifier(DeepClassifier):
             **kwargs
         )
         self.cls_dropout = cls_dropout
-        self.inputs = [
-            tf.keras.Input(shape=(None,), dtype=tf.int64, name="token_ids"),
-            tf.keras.Input(shape=(None,), dtype=tf.int64, name="type_ids"),
-        ]
 
     def build_encoding_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
         token_ids, type_ids = inputs
@@ -65,21 +59,20 @@ class BertClassifier(DeepClassifier):
             cls = Dropout(self.cls_dropout, name="cls_dropout")(cls)
         return cls
 
-    def export(self, directory: str, name: str, version: str = "0") -> None:
-        if self.is_pair_text:
-            inputs = [
-                tf.keras.Input(shape=(), dtype=tf.string, name="text_input"),
-                tf.keras.Input(shape=(), dtype=tf.string, name="context_input"),
-            ]
-        else:
-            inputs = tf.keras.Input(shape=(), dtype=tf.string, name="text_input")
-        preprocessing_layer = BertPreprocessingLayer(self.text2vec.vocab.sorted_tokens)
-        token_ids, type_ids = preprocessing_layer(inputs)
+    def export(self, directory: str, name: str, version: str = "0", **kwargs) -> None:
+        num_inputs = self._inference_kwargs.get("num_inputs", 1)
+        inputs = tf.keras.Input(shape=(num_inputs,), dtype=tf.string, name="text_input")
+        preprocessing_layer = BertPreprocessingLayer(
+            self.text2vec.vocab.sorted_tokens,
+            max_length=self.max_sequence_length - (num_inputs + 1),
+        )
+
+        token_ids, type_ids, _, _ = preprocessing_layer(inputs)
         original_model = self._inference_model
         self._inference_model = tf.keras.Model(
             inputs=inputs, outputs=self._inference_model([token_ids, type_ids])
         )
-        super().export(directory, name, version=version)
+        super(DeepClassifier, self).export(directory, name, version=version, **kwargs)
         self._inference_model = original_model
 
     def get_config(self) -> dict[str, Any]:
