@@ -42,7 +42,8 @@ class CNNClassifier(DeepClassifier):
         self.cnn_activation = cnn_activation
         self.cnn_dropout = cnn_dropout
 
-    def build_encoding_layer(self, inputs: tf.Tensor) -> tf.Tensor:
+    def build_encoding_layer(self, inputs: list[tf.Tensor]) -> tf.Tensor:
+        inputs = inputs[0]
         embeddings = self.text2vec(inputs)
         mask = tf.math.not_equal(inputs, 0)
         return DilatedConvBlock(
