@@ -6,9 +6,13 @@ import pandas as pd
 import tensorflow as tf
 
 from sknlp.data import ClassificationDataset
-from sknlp.layers import MLPLayer
+from sknlp.layers import MLPLayer, PreprocessingLayer
 from sknlp.losses import MultiLabelCategoricalCrossentropy
-from sknlp.metrics import PrecisionWithLogits, RecallWithLogits, FBetaScoreWithLogits
+from sknlp.metrics import (
+    SparsePrecisionWithLogits,
+    SparseRecallWithLogits,
+    SparseFBetaScoreWithLogits,
+)
 from sknlp.utils.classification import (
     logits2probabilities,
     probabilities2classes,
@@ -21,13 +25,12 @@ from ..text2vec import Text2vec
 
 class DeepClassifier(SupervisedNLPModel):
     dataset_class = ClassificationDataset
-    dataset_args = ["is_multilabel", "is_pair_text"]
+    dataset_args = ["is_multilabel"]
 
     def __init__(
         self,
         classes: Sequence[str],
         is_multilabel: bool = True,
-        is_pair_text: bool = False,
         max_sequence_length: Optional[int] = None,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
@@ -49,22 +52,21 @@ class DeepClassifier(SupervisedNLPModel):
             task="classification",
             **kwargs,
         )
-        self._is_pair_text = is_pair_text
-        self._is_multilabel = is_multilabel and not is_pair_text
+        self._is_multilabel = is_multilabel
         self._loss = loss
         self._loss_kwargs = loss_kwargs
         self.num_fc_layers = num_fc_layers
         self.fc_hidden_size = fc_hidden_size
         self.fc_activation = fc_activation
+        self.inputs = [
+            tf.keras.Input(shape=(None,), dtype=tf.int64, name="token_ids"),
+            tf.keras.Input(shape=(None,), dtype=tf.int64, name="type_ids"),
+        ]
 
     @property
     def is_multilabel(self) -> bool:
         return self._is_multilabel
 
-    @property
-    def is_pair_text(self) -> bool:
-        return self._is_pair_text
-
     @property
     def thresholds(self) -> list[float]:
         _thresholds = [0.5 for _ in range(self.num_classes)]
@@ -78,20 +80,15 @@ class DeepClassifier(SupervisedNLPModel):
 
     @thresholds.setter
     def thresholds(self, thresholds: Union[list[float], dict[str, float]]) -> None:
-        if (
-            isinstance(thresholds, list)
-            and len(thresholds) != self.num_classes
-            and len(thresholds) - 1 != self.num_classes
-        ):
+        if isinstance(thresholds, list) and len(thresholds) != self.num_classes:
             raise ValueError(
-                f"类别数为{self.num_classes - 1}(不含NULL类别), "
-                f"但`thresholds`长度为{len(thresholds)}."
+                f"类别数为{self.num_classes}, " f"但`thresholds`长度为{len(thresholds)}."
             )
         elif isinstance(thresholds, dict):
             _thresholds = self.thresholds
             for c, t in thresholds.items():
                 _thresholds[self.class2idx(c)] = t
-        self._inference_kwargs["thresholds"] = dict(zip(self.classes[1:], thresholds))
+        self._inference_kwargs["thresholds"] = dict(zip(self.classes, thresholds))
 
     def get_loss(self, *args, **kwargs) -> list[tf.keras.losses.Loss]:
         if self.is_multilabel:
@@ -99,7 +96,7 @@ class DeepClassifier(SupervisedNLPModel):
                 return tf.keras.losses.BinaryCrossentropy(from_logits=True)
             return MultiLabelCategoricalCrossentropy()
         else:
-            return tf.keras.losses.CategoricalCrossentropy(from_logits=True)
+            return tf.keras.losses.SparseCategoricalCrossentropy(from_logits=True)
 
     def get_metrics(self, *args, **kwargs) -> list[tf.keras.metrics.Metric]:
         activation = "sigmoid" if self.is_multilabel else "softmax"
@@ -107,9 +104,9 @@ class DeepClassifier(SupervisedNLPModel):
         if self.num_classes == 2:
             class_id = 1
         return [
-            PrecisionWithLogits(activation=activation, class_id=class_id),
-            RecallWithLogits(activation=activation, class_id=class_id),
-            FBetaScoreWithLogits(
+            SparsePrecisionWithLogits(activation=activation, class_id=class_id),
+            SparseRecallWithLogits(activation=activation, class_id=class_id),
+            SparseFBetaScoreWithLogits(
                 self.num_classes, activation=activation, class_id=class_id
             ),
         ]
@@ -174,12 +171,29 @@ class DeepClassifier(SupervisedNLPModel):
             self.classes[1:] if self.num_classes > 2 else self.classes,
         )
 
+    def export(self, directory: str, name: str, version: str = "0", **kwargs) -> None:
+        num_inputs = self._inference_kwargs.get("num_inputs", 1)
+        inputs = tf.keras.Input(
+            shape=(num_inputs, None),
+            dtype=tf.int64,
+            name="token_ids_input",
+        )
+        preprocessing_layer = PreprocessingLayer(
+            self.vocab[self.vocab.bos],
+            self.vocab[self.vocab.eos],
+            max_length=self.max_sequence_length - (num_inputs + 1),
+        )
+
+        token_ids, type_ids = preprocessing_layer(inputs)
+        original_model = self._inference_model
+        self._inference_model = tf.keras.Model(
+            inputs=inputs, outputs=self._inference_model([token_ids, type_ids])
+        )
+        super(DeepClassifier, self).export(directory, name, version=version, **kwargs)
+        self._inference_model = original_model
+
     def get_config(self) -> dict[str, Any]:
-        return {
-            **super().get_config(),
-            "is_multilabel": self.is_multilabel,
-            "is_pair_text": self.is_pair_text,
-        }
+        return {**super().get_config(), "is_multilabel": self.is_multilabel}
 
     @classmethod
     def from_config(cls, config: dict[str, Any]) -> "DeepClassifier":
