@@ -8,7 +8,8 @@ from .rnn_classifier import RNNClassifier
 
 
 class RCNNClassifier(RNNClassifier):
-    def build_encoding_layer(self, inputs: tf.Tensor) -> list[tf.Tensor]:
+    def build_encoding_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
+        inputs = inputs[0]
         embeddings = self.text2vec(inputs)
         mask = tf.math.not_equal(inputs, 0)
         return [
