@@ -40,7 +40,8 @@ class RNNClassifier(DeepClassifier):
         self.rnn_dropout = rnn_dropout
         self.rnn_recurrent_dropout = rnn_recurrent_dropout
 
-    def build_encoding_layer(self, inputs: tf.Tensor) -> tf.Tensor:
+    def build_encoding_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
+        inputs = inputs[0]
         embeddings = self.text2vec(inputs)
         mask = tf.math.not_equal(inputs, 0)
         return (
