@@ -19,7 +19,6 @@ class BertRetriever(DeepRetriever):
 
     def __init__(
         self,
-        classes: Sequence[int] = (0, 1),
         max_sequence_length: int = 120,
         projection_size: Optional[int] = None,
         temperature: float = 0.05,
@@ -30,7 +29,6 @@ class BertRetriever(DeepRetriever):
         **kwargs
     ) -> None:
         super().__init__(
-            classes,
             algorithm="bert",
             projection_size=projection_size,
             temperature=temperature,
@@ -62,13 +60,18 @@ class BertRetriever(DeepRetriever):
             cls = Dropout(self.cls_dropout, name="cls_dropout")(cls)
         return super().build_intermediate_layer(cls)
 
-    def export(self, directory: str, name: str, version: str = "0") -> None:
-        inputs = tf.keras.Input(shape=(), dtype=tf.string, name="text_input")
-        preprocessing_layer = BertPreprocessingLayer(self.text2vec.vocab.sorted_tokens)
-        token_ids, type_ids = preprocessing_layer(inputs)
+    def export(self, directory: str, name: str, version: str = "0", **kwargs) -> None:
+        num_inputs = self._inference_kwargs.get("num_inputs", 1)
+        inputs = tf.keras.Input(shape=(num_inputs,), dtype=tf.string, name="text_input")
+        preprocessing_layer = BertPreprocessingLayer(
+            self.text2vec.vocab.sorted_tokens,
+            max_length=self.max_sequence_length - (num_inputs + 1),
+        )
+        token_ids, type_ids, _, _ = preprocessing_layer(inputs)
+        vec = self._inference_model([token_ids, type_ids])
         original_model = self._inference_model
         self._inference_model = tf.keras.Model(
-            inputs=inputs, outputs=self._inference_model([token_ids, type_ids])
+            inputs=inputs, outputs=vec / tf.linalg.norm(vec, axis=-1, keepdims=True)
         )
-        super().export(directory, name, version=version)
+        super().export(directory, name, version=version, **kwargs)
         self._inference_model = original_model
\ No newline at end of file
