@@ -77,7 +77,7 @@ class DeepRetriever(SupervisedNLPModel):
 
     def __init__(
         self,
-        classes: Sequence[int] = (0, 1),
+        classes: Sequence[str] = ("0", "1"),
         max_sequence_length: Optional[int] = None,
         has_negative: bool = False,
         projection_size: Optional[int] = None,
@@ -138,6 +138,17 @@ class DeepRetriever(SupervisedNLPModel):
             outputs=self._model.get_layer("pooling").output,
         )
 
+    def predict_vec(
+        self,
+        X: Sequence[str] = None,
+        *,
+        dataset: RetrievalDataset = None,
+        batch_size: int = 128,
+    ) -> np.ndarray:
+        predictions = super().predict(X=X, dataset=dataset, batch_size=batch_size)
+        normalized = predictions / np.linalg.norm(predictions, axis=-1, keepdims=True)
+        return normalized[::2]
+
     def predict(
         self,
         X: Sequence[tuple[str, str]] = None,
