@@ -11,7 +11,6 @@ from .deep_retriever import DeepRetriever
 class RNNRetriever(DeepRetriever):
     def __init__(
         self,
-        classes: Sequence[str] = (0, 1),
         max_sequence_length: int = 100,
         projection_size: Optional[int] = None,
         temperature: float = 0.05,
@@ -24,7 +23,6 @@ class RNNRetriever(DeepRetriever):
         **kwargs
     ):
         super().__init__(
-            classes,
             max_sequence_length=max_sequence_length,
             projection_size=projection_size,
             temperature=temperature,
