@@ -48,7 +48,8 @@ class BertRNNTagger(BertTagger):
 
     def build_intermediate_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
         encodings = inputs[0]
-        mask = inputs[1]
+        type_ids = inputs[1]
+        mask = inputs[2]
         rnn_layer = BiLSTM(
             self.num_rnn_layers,
             self.rnn_hidden_size,
@@ -68,4 +69,4 @@ class BertRNNTagger(BertTagger):
                 noise_shape=noise_shape,
                 name="encoding_dropout",
             )(encodings)
-        return [encodings, mask, *inputs[2:]]
\ No newline at end of file
+        return [encodings, type_ids, mask, *inputs[3:]]
\ No newline at end of file
