@@ -2,7 +2,6 @@ from __future__ import annotations
 from typing import Any, Sequence, Optional
 
 import tensorflow as tf
-from tensorflow.keras.layers import Dropout
 
 from sknlp.layers import BertPreprocessingLayer, BertAttentionMaskLayer
 from sknlp.data import BertTaggingDataset
@@ -29,7 +28,6 @@ class BertTagger(DeepTagger):
     ) -> None:
         super().__init__(
             classes,
-            add_start_end_tag=True,
             output_format=output_format,
             global_pointer_head_size=global_pointer_head_size,
             crf_learning_rate_multiplier=crf_learning_rate_multiplier,
@@ -42,41 +40,29 @@ class BertTagger(DeepTagger):
             text_normalization=text_normalization,
             **kwargs
         )
-        self.inputs = [
-            tf.keras.Input(shape=(None,), dtype=tf.int64, name="token_ids"),
-            tf.keras.Input(shape=(None,), dtype=tf.int64, name="type_ids"),
-        ]
-
-        if self.output_format == "bio":
-            self.inputs.append(
-                tf.keras.Input(shape=(None,), dtype=tf.int32, name="tag_id")
-            )
 
     def build_encoding_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
         if self.output_format == "bio":
             token_ids, type_ids, tag_ids = inputs
         else:
             token_ids, type_ids = inputs
-        mask_layer = tf.keras.layers.Lambda(
-            lambda ids: tf.not_equal(ids, 0), name="mask_layer"
-        )
-        mask = mask_layer(token_ids)
+        mask = tf.not_equal(token_ids, 0)
 
         outputs = [
             self.text2vec(
                 [token_ids, type_ids, BertAttentionMaskLayer()([type_ids, mask])]
             )[1],
+            type_ids,
             mask,
         ]
         if self.output_format == "bio":
             outputs.append(tag_ids)
         return outputs
 
-    def export(self, directory: str, name: str, version: str = "0") -> None:
-        inputs = tf.keras.Input(shape=(), dtype=tf.string, name="text_input")
-        preprocessing_layer = BertPreprocessingLayer(
-            self.text2vec.vocab.sorted_tokens, return_offset=True
-        )
+    def export(self, directory: str, name: str, version: str = "0", **kwargs) -> None:
+        num_inputs = self._inference_kwargs.get("num_inputs", 1)
+        inputs = tf.keras.Input(shape=(num_inputs,), dtype=tf.string, name="text_input")
+        preprocessing_layer = BertPreprocessingLayer(self.text2vec.vocab.sorted_tokens)
         token_ids, type_ids, starts, ends = preprocessing_layer(inputs)
         fill_value = tf.float32.min
         if self.output_format == "bio":
@@ -87,10 +73,9 @@ class BertTagger(DeepTagger):
         self._inference_model = tf.keras.Model(
             inputs=inputs, outputs=[predictions, starts, ends]
         )
-        super(DeepTagger, self).export(directory, name, version=version)
+        super(DeepTagger, self).export(directory, name, version=version, **kwargs)
         self._inference_model = original_model
 
     @classmethod
     def from_config(cls, config: dict[str, Any]) -> "BertTagger":
-        config.pop("add_start_end_tag")
         return super().from_config(config)
\ No newline at end of file
