@@ -46,23 +46,13 @@ class CNNTagger(DeepTagger):
         self.cnn_kernel_size = cnn_kernel_size
         self.cnn_max_dilation = cnn_max_dilation
         self.cnn_activation = cnn_activation
-        if self.output_format == "bio":
-            self.inputs = [
-                tf.keras.Input(shape=(None,), dtype=tf.int32, name="token_id"),
-                tf.keras.Input(shape=(None,), dtype=tf.int32, name="tag_id"),
-            ]
-        else:
-            self.inputs = tf.keras.Input(shape=(None,), dtype=tf.int32, name="token_id")
 
     def build_encoding_layer(self, inputs: tf.Tensor) -> tf.Tensor:
         if self.output_format == "bio":
-            token_ids, tag_ids = inputs
+            token_ids, type_ids, tag_ids = inputs
         else:
-            token_ids = inputs
-        mask_layer = tf.keras.layers.Lambda(
-            lambda ids: tf.not_equal(ids, 0), name="mask_layer"
-        )
-        mask = mask_layer(token_ids)
+            token_ids, type_ids = inputs
+        mask = tf.not_equal(token_ids, 0)
 
         embeddings = self.text2vec(token_ids)
         outputs = [
@@ -74,6 +64,7 @@ class CNNTagger(DeepTagger):
                 activation=self.cnn_activation,
                 return_sequences=True,
             )(embeddings, mask),
+            type_ids,
             mask,
         ]
         if self.output_format == "bio":
