@@ -1,5 +1,6 @@
 from __future__ import annotations
 from typing import Sequence, Any, Optional
+from numpy import equal
 
 import pandas as pd
 import tensorflow as tf
@@ -22,12 +23,11 @@ from ..text2vec import Text2vec
 
 class DeepTagger(SupervisedNLPModel):
     dataset_class = TaggingDataset
-    dataset_args = ["output_format", "add_start_end_tag"]
+    dataset_args = ["output_format"]
 
     def __init__(
         self,
         classes: Sequence[str],
-        add_start_end_tag: bool = False,
         output_format: str = "global_pointer",
         global_pointer_head_size: int = 64,
         crf_learning_rate_multiplier: float = 1.0,
@@ -38,7 +38,6 @@ class DeepTagger(SupervisedNLPModel):
         text2vec: Optional[Text2vec] = None,
         **kwargs,
     ):
-        self._add_start_end_tag = add_start_end_tag
         if output_format not in {"bio", "global_pointer"}:
             raise ValueError(
                 f"output_format必须为'bio'或者'global_pointer', 目前为{output_format}"
@@ -59,10 +58,18 @@ class DeepTagger(SupervisedNLPModel):
         self.fc_hidden_size = fc_hidden_size
         self.fc_activation = fc_activation
         self.global_pointer_head_size = global_pointer_head_size
+        self.inputs = [
+            tf.keras.Input(shape=(None,), dtype=tf.int64, name="token_ids"),
+            tf.keras.Input(shape=(None,), dtype=tf.int64, name="type_ids"),
+        ]
+        if self.output_format == "bio":
+            self.inputs.append(
+                tf.keras.Input(shape=(None,), dtype=tf.int32, name="tag_ids")
+            )
 
     @property
     def add_start_end_tag(self) -> bool:
-        return self._add_start_end_tag
+        return True
 
     @property
     def output_format(self) -> str:
@@ -104,8 +111,18 @@ class DeepTagger(SupervisedNLPModel):
             return "val_fbeta_score"
 
     def build_output_layer(self, inputs: list[tf.Tensor]) -> list[tf.Tensor]:
+        boolean_mask_layer = tf.keras.layers.Lambda(
+            lambda inputs: tf.math.logical_and(inputs[0], tf.equal(inputs[1], 0)),
+            name="boolean_mask_layer",
+        )
+        mask_layer = tf.keras.layers.Lambda(
+            lambda inputs: tf.ragged.boolean_mask(inputs[0], inputs[1]).to_tensor(),
+            name="mask_layer",
+        )
         if self.output_format == "bio":
-            encodings, mask, tag_ids = inputs
+            encodings, type_ids, mask, tag_ids = inputs
+            boolean_mask = boolean_mask_layer([mask, type_ids])
+            encodings = tf.ragged.boolean_mask(encodings, boolean_mask).to_tensor()
             emissions = MLPLayer(
                 self.num_fc_layers,
                 hidden_size=self.fc_hidden_size,
@@ -113,19 +130,23 @@ class DeepTagger(SupervisedNLPModel):
                 activation=self.fc_activation,
                 name="mlp",
             )(encodings)
+            new_mask = mask_layer([mask, boolean_mask])
             crf_layer = CrfLossLayer(self.num_bio_tags)
             if self.crf_learning_rate_multiplier != 1:
                 self._layerwise_learning_rate_multiplier.append(
                     (crf_layer, self.crf_learning_rate_multiplier)
                 )
-            return crf_layer([emissions, tag_ids], mask)
+            return crf_layer([emissions, tag_ids], new_mask)
         else:
-            encodings, mask = inputs
+            encodings, type_ids, mask = inputs
+            boolean_mask = boolean_mask_layer([mask, type_ids])
+            encodings = tf.ragged.boolean_mask(encodings, boolean_mask).to_tensor()
+            new_mask = mask_layer([mask, boolean_mask])
             return GlobalPointerLayer(
                 self.num_classes,
                 self.global_pointer_head_size,
-                self.max_sequence_length + 2 * self.add_start_end_tag,
-            )(encodings, mask)
+                self.max_sequence_length * 2,
+            )(encodings, new_mask)
 
     def predict(
         self,
@@ -137,7 +158,12 @@ class DeepTagger(SupervisedNLPModel):
     ) -> list[list[Tag]]:
         dataset = self.prepare_dataset(X, None, dataset, evaluation=True)
         raw_predictions = super().predict(X, dataset=dataset, batch_size=batch_size)
-        tokens_list = dataset.tokenize(dataset.X)
+        inputs = dataset.X
+        if isinstance(inputs[0], list):
+            texts = [i[0] for i in inputs]
+        else:
+            texts = inputs
+        tokens_list = dataset.tokenize(texts)
         predictions: list[list[Tag]] = []
         if self.output_format == "bio":
             for tag_ids, tokens in zip(raw_predictions, tokens_list):
@@ -225,4 +251,5 @@ class DeepTagger(SupervisedNLPModel):
     def from_config(cls, config: dict[str, Any]) -> "DeepTagger":
         config.pop("algorithm", None)
         config.pop("task", None)
+        config.pop("add_start_end_tag", None)
         return super().from_config(config)
\ No newline at end of file
