@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Callable, Optional, Any
+from typing import Callable, Any
 import os
 from enum import Enum
 
@@ -115,7 +115,7 @@ class ModelCheckpoint:
         cls,
         model_type: BertFamily,
         checkpoint_directory: str,
-        config_filename: Optional[str] = None,
+        config_filename: str | None = None,
     ) -> "ModelCheckpoint":
         cls.create_checkpoint_file(checkpoint_directory)
         with open(
@@ -124,10 +124,11 @@ class ModelCheckpoint:
             token_list = f.read().strip("\n").split("\n")
             vocab = Vocab(
                 token_list,
-                pad_token=token_list[0],
-                unk_token=token_list[100],
-                bos_token=token_list[101],
-                eos_token=token_list[102],
+                pad="[PAD]",
+                unk="[UNK]",
+                bos="[CLS]",
+                eos="[SEP]",
+                mask="[MASK]",
             )
         if not config_filename:
             config_filename = cls.search_config_file(checkpoint_directory)
@@ -141,12 +142,12 @@ class Bert2vec(Text2vec):
     def __init__(
         self,
         vocab: Vocab,
-        segmenter: Optional[str] = "bert",
+        segmenter: str | None = "bert",
         hidden_size: int = 768,
-        embedding_size: Optional[int] = 768,
+        embedding_size: int | None = 768,
         num_layers: int = 12,
         num_attention_heads: int = 12,
-        sequence_length: Optional[int] = None,
+        sequence_length: int | None = None,
         max_sequence_length: int = 512,
         type_vocab_size: int = 16,
         intermediate_size: int = 3072,
@@ -223,7 +224,7 @@ class Bert2vec(Text2vec):
         return inputs[-1]
 
     def __call__(
-        self, inputs: list[tf.Tensor], logits_mask: Optional[tf.Tensor] = None
+        self, inputs: list[tf.Tensor], logits_mask: tf.Tensor | None = None
     ) -> list[tf.Tensor]:
         if logits_mask is None:
             inputs.append(tf.ones_like(inputs[0]))
@@ -235,7 +236,7 @@ class Bert2vec(Text2vec):
         return outputs
 
     def update_dropout(
-        self, dropout: float, attention_dropout: Optional[float] = None
+        self, dropout: float, attention_dropout: float | None = None
     ) -> None:
         bert_layer = self.pretrain_layer
         bert_layer.embedding_dropout_layer.rate = dropout
@@ -256,10 +257,10 @@ class Bert2vec(Text2vec):
         cls,
         model_type: BertFamily,
         checkpoint_directory: str,
-        config_filename: Optional[str] = None,
-        sequence_length: Optional[int] = None,
-        dropout_rate: Optional[float] = None,
-        attention_dropout_rate: Optional[float] = None,
+        config_filename: str | None = None,
+        sequence_length: int | None = None,
+        dropout_rate: float | None = None,
+        attention_dropout_rate: float | None = None,
         enable_recompute_grad: bool = False,
         name: str = "bert2vec",
     ):
