@@ -133,13 +133,7 @@ class Word2vec(Text2vec):
                     tokens.append(token)
                 vec = list(map(float, cells[1:]))
                 weights[idx, :] = vec
-        vocab = Vocab(
-            tokens,
-            pad_token=pad,
-            unk_token=unk,
-            bos_token=bos,
-            eos_token=eos,
-        )
+        vocab = Vocab(tokens, pad=pad, unk=unk, bos=bos, eos=eos)
         if not has_unk:
             weights[1, :] = weights[4:, :].mean(axis=0)
         word2vec = cls(vocab, embedding_size, segmenter=segmenter)
