@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
 from .vocab import Vocab
 
-
-__all__ = ['Vocab']
+__all__ = ["Vocab"]
