@@ -1,6 +1,6 @@
 from __future__ import annotations
-from typing import Optional, Sequence, Any
-import json
+from typing import Sequence, Any
+
 from collections import defaultdict
 from itertools import accumulate
 
@@ -9,18 +9,25 @@ class Vocab:
     def __init__(
         self,
         tokens: Sequence[str],
-        frequencies: Optional[list[int]] = None,
+        frequencies: list[int] | None = None,
         min_frequency: int = 1,
-        pad_token: str = "<pad>",
-        unk_token: str = "<unk>",
-        bos_token: str = "<bos>",
-        eos_token: str = "<eos>",
+        pad: str = "<pad>",
+        unk: str = "<unk>",
+        bos: str = "<bos>",
+        eos: str = "<eos>",
+        mask: str = "[MASK]",
+        **kwargs,
     ) -> None:
         frequencies = frequencies or [min_frequency for _ in range(len(tokens))]
-        special_tokens = (pad_token, unk_token, bos_token, eos_token)
+        self.pad = pad
+        self.unk = unk
+        self.bos = bos
+        self.eos = eos
+        self.mask = mask
+        special_tokens = (self.pad, self.unk, self.bos, self.eos)
         special_token_index_offset = 0
         _tokens = list(tokens)
-        for special_token in (pad_token, unk_token, bos_token, eos_token):
+        for special_token in special_tokens:
             if special_token not in _tokens:
                 _tokens.insert(special_token_index_offset, special_token)
                 frequencies.insert(special_token_index_offset, min_frequency)
@@ -33,11 +40,8 @@ class Vocab:
                 self._token2idx[token] = len(self._token2idx)
                 self._token_frequency[token] = frequency
         self._idx2token = dict(zip(self._token2idx.values(), self._token2idx.keys()))
-        self._pad_token = pad_token
-        self._unk_token = unk_token
-        self._bos_token = bos_token
-        self._eos_token = eos_token
-        self.special_tokens = {self.pad, self.unk, self.bos, self.eos}
+        self.special_tokens = set(special_tokens)
+        self.special_tokens.add(self.mask)
 
     def idx2token(self, indices: int | Sequence[int]) -> str | list[str]:
         """
@@ -89,6 +93,14 @@ class Vocab:
             length -= 2
         return length
 
+    def get_token_utf8_bytes(self, token: str) -> int:
+        length = len(token.encode("UTF-8"))
+        if token in self.special_tokens:
+            length = 1
+        elif token.startswith("##"):
+            length -= 2
+        return length
+
     def create_ichar2itoken_mapping(
         self,
         tokens: Sequence[str],
@@ -116,37 +128,6 @@ class Vocab:
         end_mapping = {i: c - 1 for i, c in enumerate(cumsum)}
         return start_mapping, end_mapping
 
-    def to_json(self) -> str:
-        return json.dumps(
-            {
-                "token_frequency": self._token_frequency,
-                "token2idx": self._token2idx,
-                "unk": self.unk,
-                "pad": self.pad,
-                "bos": self.bos,
-                "eos": self.eos,
-            },
-            ensure_ascii=False,
-        )
-
-    @classmethod
-    def from_json(cls, json_str: str) -> "Vocab":
-        vocab_dict: dict[str, Any] = json.loads(json_str)
-        pad_token = vocab_dict["pad"]
-        unk_token = vocab_dict["unk"]
-        bos_token = vocab_dict["bos"]
-        eos_token = vocab_dict["eos"]
-        vocab = cls(
-            vocab_dict["token_frequency"].keys(),
-            vocab_dict["token_frequency"].values(),
-            min_frequency=1,
-            pad_token=pad_token,
-            unk_token=unk_token,
-            bos_token=bos_token,
-            eos_token=eos_token,
-        )
-        return vocab
-
     def __getitem__(self, tokens: str | Sequence[str]) -> int | list[int]:
         return self.token2idx(tokens)
 
@@ -165,22 +146,6 @@ class Vocab:
             f'eos="{self.eos}")'
         )
 
-    @property
-    def pad(self) -> str:
-        return self._pad_token
-
-    @property
-    def unk(self) -> str:
-        return self._unk_token
-
-    @property
-    def bos(self) -> str:
-        return self._bos_token
-
-    @property
-    def eos(self) -> str:
-        return self._eos_token
-
     @property
     def sorted_tokens(self) -> list[str]:
         items = sorted(self._token2idx.items(), key=lambda x: x[1])
@@ -188,4 +153,26 @@ class Vocab:
 
     @property
     def sorted_token_lengths(self) -> list[int]:
-        return [self.get_token_length(token) for token in self.sorted_tokens]
\ No newline at end of file
+        return [self.get_token_length(token) for token in self.sorted_tokens]
+
+    @property
+    def sorted_token_utf8_bytes(self) -> list[int]:
+        return [self.get_token_utf8_bytes(token) for token in self.sorted_tokens]
+
+    def get_config(self) -> dict[str, Any]:
+        return {
+            "token_frequency": self._token_frequency,
+            "token2idx": self._token2idx,
+            "unk": self.unk,
+            "pad": self.pad,
+            "bos": self.bos,
+            "eos": self.eos,
+            "mask": self.mask,
+        }
+
+    @classmethod
+    def from_config(cls, config: dict[str, Any]) -> "Vocab":
+        token_frequency = config.pop("token_frequency")
+        return cls(
+            token_frequency.keys(), frequencies=token_frequency.values(), **config
+        )
